==> xmule-1.9.1b.tar.bz2: xmule-1.9.1b/src/SafeFile.cpp <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifdef PRECOMP
    #include "xmule-headers.h"
#endif

#include "SafeFile.h"                       // Needed for this Interface's Prototype

CSafeFile::CSafeFile(LPCSTR lpszFileName, UINT nOpenFlags)
: CFile(lpszFileName, (CFile::OpenMode) nOpenFlags)
{
}

CSafeFile::CSafeFile(): CFile()
{
}

UINT CSafeFile::Read(void *lpBuf, UINT nCount)
{
    if (Tell() + nCount > Length())
    {
        //		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
        return(UINT) - 1;
    }
    return CFile::Read(lpBuf, nCount);
}

CSafeMemFile::CSafeMemFile(BYTE *lpBuffer, UINT nBufferSize, UINT nGrowBytes)
: CMemFile(lpBuffer, nBufferSize, nGrowBytes)
{
    // Nothing to do here
}

CSafeMemFile::CSafeMemFile(UINT nGrowBytes): CMemFile(nGrowBytes)
{
}

UINT CSafeMemFile::Read(void *lpBuf, UINT nCount)
{
    if (GetPosition() + nCount > this->GetLength())
    {
        //		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
        return 0;
    }
    return CMemFile::Read(lpBuf, nCount);
}

==> xmule-1.10.0.tar.bz2: xmule-1.10.0/src/SafeFile.cpp <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifdef PRECOMP
#	include "xmule-headers.h"
#else
#	include "wintypes.h"
#	include "SafeFile.h"
#endif

CSafeFile::CSafeFile(LPCSTR lpszFileName, UINT nOpenFlags)
: CFile(lpszFileName, (CFile::OpenMode) nOpenFlags)
//:CFile(lpszFileName,nOpenFlags)
{
    // Nothing to do here
}

CSafeFile::CSafeFile(): CFile()
{
}

UINT CSafeFile::Read(void *lpBuf, UINT nCount)
{
    if (Tell() + nCount > Length())
    {
        //		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
        return(UINT) - 1;
    }
    return CFile::Read(lpBuf, nCount);
}

CSafeMemFile::CSafeMemFile(BYTE *lpBuffer, UINT nBufferSize, UINT nGrowBytes)
: CMemFile(lpBuffer, nBufferSize, nGrowBytes)
{
    // Nothing to do here
}

CSafeMemFile::CSafeMemFile(UINT nGrowBytes): CMemFile(nGrowBytes)
{
}

UINT CSafeMemFile::Read(void *lpBuf, UINT nCount)
{
    if (GetPosition() + nCount > this->GetLength())
    {
        //		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
        return 0;
    }
    return CMemFile::Read(lpBuf, nCount);
}
